# core Python packages
import logging


# third party packages


# django packages
from django.shortcuts import render
from django.utils.timezone import utc


# local imports
import utils

# start a logger
logger = logging.getLogger('default')


# Create your views here.
def index(request):
    logger.debug('Core index requested')
    
    installed_modules = utils.installed_modules()
    
    logger.debug('Component modules detected:')
    [logger.debug('%s: %s' % (k, v)) for k, v in installed_modules.iteritems()]

    context = {
        'title': 'The Django-HCUP Hachoir: Core Index', 
        'djhcup_components': installed_modules,
        }
    
    template = 'djhcup_core_index.html'
    return render(request, template, context)




# Django imports
from django.conf.urls import patterns, include, url


# local imports
import utils


# base patterns always available through having djhcup_core installed
urlpatterns = patterns('',
    url(r'^$', 'djhcup_core.views.index', name='index'),
)


# check for installed modules, and include url patterns from each
installed_mods = utils.installed_modules()


# tack on url patterns for installed component modules
# these are always prefixed by the module name e.g. /staging/batches/
for mod, installed in installed_mods.iteritems():
    
    # but don't add core urls (this file) again
    if installed is True and mod is not 'djhcup_core':
        prefix = mod.split('_')[-1]
        urlpatterns += patterns('',
                                url(r'^%s/' % prefix, include('%s.urls' % mod)),
                                )


# core Python packages
import importlib


def installed_modules():
    """Check for installed modules and return list with relevant data
    """
    # detect presence/absence of component modules
    module_names = ['djhcup_core',
                    'djhcup_staging',
                    'djhcup_norm',
                    'djhcup_recomb']
    installed = {}

    for x in module_names:
        # TODO: Rewrite to pull version numbers for each of these as well
        try:
            module = importlib.import_module(x)
            installed[x] = True
        except ImportError:
            installed[x] = False
    
    if len(installed) > 0:
        return installed
    else:
        return False
